import sys,os
sys.path.append(os.path.abspath('../'))

from viiapackage import *
import numpy as np

project = viia_create_project('exercise-5-model')

project.read_dump("exercise5.json")

def rot(vector,theta):
    """
    Rotates 2-D vector around z-axis
    
    Input:
        axis (list): List of 2d coordinates that describe axis to be rotated.
        theta (float): angle in degrees to rotate around specified axis
    
    Output:
        matrix: rotated vector
    """
    theta=theta/180.0*np.pi    
    R = np.array([[np.cos(theta), -np.sin(theta)],[np.sin(theta), np.cos(theta)]])
    return np.dot(R,vector)

def rotation_matrix(axis, theta):
    """
    Return the rotation matrix associated with counterclockwise rotation about
    the given axis by theta radians.
    
    Input:
        axis (list): List of 3d coordinates that describe axis around which a vector needs to be rotated.
        theta (float): angle in dgerees to rotate around specified axis
    
    Output:
        matrix: rotational matrix
    
    """
    theta=theta/180.0*np.pi    
    axis = np.asarray(axis)
    axis = axis / np.sqrt(np.dot(axis, axis))
    a = np.cos(theta / 2.0)
    b, c, d = -axis * np.sin(theta / 2.0)
    aa, bb, cc, dd = a * a, b * b, c * c, d * d
    bc, ad, ac, ab, bd, cd = b * c, a * d, a * c, a * b, b * d, c * d
    return np.array([[aa + bb - cc - dd, 2 * (bc + ad), 2 * (bd - ac)],
                     [2 * (bc - ad), aa + cc - bb - dd, 2 * (cd + ab)],
                     [2 * (bd + ac), 2 * (cd - ab), aa + dd - bb - cc]])


roof_E = project.get_shape("roofs","N2-DAKEN-LIN-HBV-PLANKEN-0.018-0.1149-0.1149-0.6-1")
roof_F = project.get_shape("roofs","N2-DAKEN-LIN-HBV-PLANKEN-0.018-0.1149-0.1149-0.6-2")


vector_x = rot([7, 0], -30)
vector_y = rot([0, 13], -30)

rot_matrix = rotation_matrix([vector_y[0]/13, vector_y[1]/13, 0], 30.)
rot_matrix_2 = rotation_matrix([vector_y[0]/13, vector_y[1]/13, 0], -30.)
direction = np.dot(rot_matrix, fem_unit_vector(
    [-vector_x[0], -vector_x[1], 0]))
direction_2 = np.dot(rot_matrix_2, fem_unit_vector(
    [vector_x[0], vector_x[1], 0]))


point_A = [vector_y[0]/2, vector_y[1]/2, 0]
point_B = [vector_y[0]/2+vector_x[0], vector_y[1]/2+vector_x[1], 0]
point_C = [vector_y[0]/2+vector_x[0]/2, vector_y[1]/2+vector_x[1]/2, 3.5]
point_D = [vector_y[0]/2+vector_x[0]/2, vector_y[1]/2+vector_x[1]/2, 0]
point_E = fem_point_to_plane(point_D, roof_E.contour.get_points(), direction)
point_F = fem_point_to_plane(point_D, roof_F.contour.get_points(), direction_2)

project.viia_create_beam(name='N1-BALKEN-LIN-HOUT-75x180-1',
                        material = 'LIN-HOUT',
                        geometry = '75x180',
                        points = [point_A, point_B])

project.viia_create_beam(name='N1-BALKEN-LIN-HOUT-75x180-2',
                        material = 'LIN-HOUT',
                        geometry = '75x180',
                        points = [point_A, point_C])

project.viia_create_beam(name='N1-BALKEN-LIN-HOUT-75x180-3',
                        material = 'LIN-HOUT',
                        geometry = '75x180',
                        points = [point_C, point_B])

project.viia_create_beam(name='N1-BALKEN-LIN-HOUT-75x180-4',
                        material = 'LIN-HOUT',
                        geometry = '75x180',
                        points = [point_D, point_E])
project.viia_create_beam(name='N1-BALKEN-LIN-HOUT-75x180-4',
                        material = 'LIN-HOUT',
                        geometry = '75x180',
                        points = [point_D, point_F])


project.connect_all_shapes()
project.create_model(software="diana")
